.. image:: https://raw.githubusercontent.com/pyQode/pyQode/master/media/pyqode-banner.png

|

.. image:: https://img.shields.io/pypi/v/pyqode.rst.svg
   :target: https://pypi.python.org/pypi/pyqode.rst/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/pyqode.rst.svg
   :target: https://pypi.python.org/pypi/pyqode.rst/
   :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/l/pyqode.rst.svg


.. image:: https://travis-ci.org/pyQode/pyqode.rst.svg?branch=master
   :target: https://travis-ci.org/pyQode/pyqode.rst
   :alt: Travis-CI build status


.. image:: https://coveralls.io/repos/pyQode/pyqode.rst/badge.svg?branch=master
   :target: https://coveralls.io/r/pyQode/pyqode.rst?branch=master
   :alt: Coverage Status


About
-----

Adds reStructuredText support to pyQode
